@@ -133,7 +133,7 @@ struct _GkdSecretService {
 	GkdSecretObjects *objects;
 	GHashTable *aliases;
 	GckSession *internal_session;
-	gchar *alias_directory;
+	gchar *default_path;
 };
 
 typedef struct _ServiceClient {
@@ -150,65 +150,57 @@ G_DEFINE_TYPE (GkdSecretService, gkd_secret_service, G_TYPE_OBJECT);
  */
 
 static gchar*
-default_path (GkdSecretService *self)
+get_default_path (void)
 {
 	gchar *old_directory;
 	gchar *new_directory;
+	gchar *alias_directory = NULL;
 
 #if WITH_DEBUG
-	if (self->alias_directory == NULL) {
-		const gchar *path = g_getenv ("GNOME_KEYRING_TEST_PATH");
-		if (path && path[0]) {
-			self->alias_directory = g_strdup (path);
-			g_debug ("Alias directory was overridden by tests: %s", path);
-		}
+	const gchar *path = g_getenv ("GNOME_KEYRING_TEST_PATH");
+	if (path && path[0]) {
+		alias_directory = g_strdup (path);
+		g_debug ("Alias directory was overridden by tests: %s", path);
 	}
 #endif
 
-	if (self->alias_directory == NULL) {
+	if (alias_directory == NULL) {
 		new_directory = g_build_filename (g_get_user_data_dir (), "keyrings", NULL);
 		old_directory = g_build_filename (g_get_home_dir (), ".gnome2", "keyrings", NULL);
 
 		if (!g_file_test (new_directory, G_FILE_TEST_IS_DIR) &&
 		    g_file_test (old_directory, G_FILE_TEST_IS_DIR)) {
-			self->alias_directory = old_directory;
+			alias_directory = old_directory;
 			old_directory = NULL;
 		} else {
-			self->alias_directory = new_directory;
+			alias_directory = new_directory;
 			new_directory = NULL;
 		}
 
 		g_free (old_directory);
 		g_free (new_directory);
-		g_debug ("keyring alias directory: %s", self->alias_directory);
+		g_debug ("keyring alias directory: %s", alias_directory);
 	}
 
-	return g_build_filename (self->alias_directory, "default", NULL);
+	return g_build_filename (alias_directory, "default", NULL);
 }
 
 static void
-update_default (GkdSecretService *self, gboolean force)
+update_default (GkdSecretService *self)
 {
 	gchar *contents = NULL;
-	const gchar *identifier;
-	gchar *path;
 
-	if (!force) {
-		identifier = g_hash_table_lookup (self->aliases, "default");
-		if (identifier)
-			return;
-	}
-
-	path = default_path (self);
-	if (g_file_get_contents (path, &contents, NULL, NULL)) {
+	if (g_file_get_contents (self->default_path, &contents, NULL, NULL)) {
 		g_strstrip (contents);
 		if (!contents[0]) {
 			g_free (contents);
 			contents = NULL;
 		}
 	}
-	g_free (path);
 
+	/* Default to to 'login' if no default keyring */
+	if (contents == NULL)
+		contents = g_strdup ("login");
 	g_hash_table_replace (self->aliases, g_strdup ("default"), contents);
 }
 
@@ -217,16 +209,13 @@ store_default (GkdSecretService *self)
 {
 	GError *error = NULL;
 	const gchar *identifier;
-	gchar *path;
 
 	identifier = g_hash_table_lookup (self->aliases, "default");
 	if (!identifier)
 		return;
 
-	path = default_path (self);
-	if (!g_file_set_contents (path, identifier, -1, &error))
+	if (!g_file_set_contents (self->default_path, identifier, -1, &error))
 		g_message ("couldn't store default keyring: %s", egg_error_message (error));
-	g_free (path);
 }
 
 static gboolean
@@ -295,7 +284,7 @@ initialize_service_client (GkdSecretService *self,
 	g_hash_table_replace (self->clients, client->caller_peer, client);
 
 	/* Update default collection each time someone connects */
-	update_default (self, TRUE);
+	update_default (self);
 }
 
 static void
@@ -332,6 +321,59 @@ ensure_client_for_sender (gpointer user_data)
 	return FALSE;
 }
 
+static GDBusMessage *
+rewrite_default_alias (GkdSecretService *self,
+                       GDBusMessage *message)
+{
+	const char *path = g_dbus_message_get_path (message);
+	const char *replace;
+	char *collection = NULL, *item = NULL;
+	char *collection_path, *item_path;
+	GDBusMessage *rewritten;
+	GError *error = NULL;
+
+	if (path == NULL)
+		return message;
+
+	if (!g_str_has_prefix (path, SECRET_ALIAS_PREFIX))
+		return message;
+
+	if (!gkd_secret_util_parse_path (path, &collection, &item))
+		return message;
+
+	replace = gkd_secret_service_get_alias (self, collection);
+	if (!replace) {
+		g_free (item);
+		g_free (collection);
+		return message;
+	}
+
+	rewritten = g_dbus_message_copy (message, &error);
+	if (error != NULL) {
+		g_error_free (error);
+		return message;
+	}
+
+	collection_path = gkd_secret_util_build_path (SECRET_COLLECTION_PREFIX,
+						      replace, -1);
+
+	if (item != NULL) {
+		item_path = gkd_secret_util_build_path (collection_path,
+							item, -1);
+		g_dbus_message_set_path (rewritten, item_path);
+		g_free (item_path);
+	} else {
+		g_dbus_message_set_path (rewritten, collection_path);
+	}
+
+	g_free (collection_path);
+	g_free (item);
+	g_free (collection);
+	g_object_unref (message);
+
+	return rewritten;
+}
+
 static GDBusMessage *
 service_message_filter (GDBusConnection *connection,
 			GDBusMessage *message,
@@ -340,13 +382,16 @@ service_message_filter (GDBusConnection *connection,
 {
 	GkdSecretService *self = user_data;
 	MessageFilterData *data;
+	GDBusMessage *filtered;
 
 	if (!incoming)
 		return message;
 
+	filtered = rewrite_default_alias (self, message);
+
 	data = g_slice_new0 (MessageFilterData);
 	data->service = g_object_ref (self);
-	data->message = g_object_ref (message);
+	data->message = g_object_ref (filtered);
 
 	/* We use G_PRIORITY_HIGH to make sure this timeout is
 	 * scheduled before the actual method call.
@@ -354,7 +399,7 @@ service_message_filter (GDBusConnection *connection,
 	g_idle_add_full (G_PRIORITY_HIGH, ensure_client_for_sender,
 			 data, NULL);
 
-	return message;
+	return filtered;
 }
 
 /* -----------------------------------------------------------------------------
@@ -905,6 +950,17 @@ gkd_secret_service_init_collections (GkdSecretService *self)
 	g_strfreev (collections);
 }
 
+static void
+gkd_secret_service_init_aliases (GkdSecretService *self)
+{
+	self->aliases = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	g_hash_table_insert (self->aliases, g_strdup ("session"), g_strdup ("session"));
+	/* TODO: We should be using CKA_G_LOGIN_COLLECTION */
+	g_hash_table_insert (self->aliases, g_strdup ("login"), g_strdup ("login"));
+
+	update_default (self);
+}
+
 static GObject*
 gkd_secret_service_constructor (GType type,
 				guint n_props,
@@ -1000,7 +1056,8 @@ static void
 gkd_secret_service_init (GkdSecretService *self)
 {
 	self->clients = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, free_client);
-	self->aliases = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	self->default_path = get_default_path ();
+	gkd_secret_service_init_aliases (self);
 }
 
 static void
@@ -1050,8 +1107,8 @@ gkd_secret_service_finalize (GObject *obj)
 	g_hash_table_destroy (self->aliases);
 	self->aliases = NULL;
 
-	g_free (self->alias_directory);
-	self->alias_directory = NULL;
+	g_free (self->default_path);
+	self->default_path = NULL;
 
 	G_OBJECT_CLASS (gkd_secret_service_parent_class)->finalize (obj);
 }
@@ -1284,38 +1341,10 @@ gkd_secret_service_close_session (GkdSecretService *self, GkdSecretSession *sess
 const gchar*
 gkd_secret_service_get_alias (GkdSecretService *self, const gchar *alias)
 {
-	const gchar *identifier;
-
 	g_return_val_if_fail (GKD_SECRET_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (alias != NULL, NULL);
 
-	identifier =  g_hash_table_lookup (self->aliases, alias);
-	if (!identifier) {
-		if (g_str_equal (alias, "default")) {
-			update_default (self, TRUE);
-			identifier = g_hash_table_lookup (self->aliases, alias);
-
-			/* Default to to 'login' if no default keyring */
-			if (identifier == NULL) {
-				identifier = "login";
-				g_hash_table_replace (self->aliases, g_strdup (alias),
-						      g_strdup (identifier));
-			}
-
-		} else if (g_str_equal (alias, "session")) {
-			identifier = "session";
-			g_hash_table_replace (self->aliases, g_strdup (alias),
-					      g_strdup (identifier));
-
-		/* TODO: We should be using CKA_G_LOGIN_COLLECTION */
-		} else if (g_str_equal (alias, "login")) {
-			identifier = "login";
-			g_hash_table_replace (self->aliases, g_strdup (alias),
-					      g_strdup (identifier));
-		}
-	}
-
-	return identifier;
+	return g_hash_table_lookup (self->aliases, alias);
 }
 
 void
